import React from "react";
import ReactDOM from "react-dom";
import {Icon} from 'react-fa';
import { connect } from 'react-redux';
import { Field, reduxForm  } from 'redux-form';
import "../../styles/dropdown.scss";
import {actionToggleDropdown} from '../../actions/dropdown'
import translate from 'redux-polyglot/translate';
import { actionSubscribe } from "../../actions/connection"



class SignupForm extends React.Component {

    render() {

        const { handleSubmit, pristine, submitting } = this.props

        return (
            <form onSubmit={handleSubmit}>
                <div className="dropdown-menu-item">
                    <Field name="email" component="input" type="text" placeholder="Email"/>
                </div>
                <div className="dropdown-menu-item">
                    <Field name="password" component="input" type="password" placeholder="Password"/>
                </div>
                <div className="dropdown-menu-item">
                    <button type="submit" disabled={pristine || submitting}><translate>Sign up</translate></button>
                </div>
            </form>
        )
    }
}

SignupForm = reduxForm({
    form : "signin"
})(SignupForm)

SignupForm = translate(SignupForm);

class DropdownSigninComponent extends React.Component {

  render() {

    let {user} = this.props;
    let arrow = <Icon name="angle-down"></Icon>;
    let hidden = 'hide';

    if (this.props.open) {
      arrow = <Icon name="angle-up"></Icon>;
      hidden = '';
    }

    return (
      <div className="dropdown">
      <div className="dropdown-header" onClick={this.props.onToggle}>

      </div>
      <div className={"dropdown-menu "+hidden}>
        <SignupForm onSubmit={this.props.handleSubmit} />
      </div>
    </div>
    )
  }
}

DropdownSigninComponent = translate(DropdownSigninComponent);

/******************************************************************/

const mapStateToProps = (state) => {

  return {
    open : state.dropdown.open,
    name : state.dropdown.name,
    form : state.form.signin
  }
};

const mapDispatchToProps = (dispatch, ownProps) => {
  return {
    onToggleDispatch : (open) => {
      dispatch(actionToggleDropdown(open))
    },
    onSubmit(values) {
        dispatch(actionSubscribe(values))
    }
  }
};

const mergeProps = (stateProps, dispatchProps, ownProps) => {

  return {
    ...{ ...stateProps, ...dispatchProps },
    ...{
      onToggle : () => {
        dispatchProps.onToggleDispatch(stateProps.open)
    },
    handleSubmit : () => {
      dispatchProps.onSubmit(stateProps.form.values)
    },
    }
  }
}

const DropdownSignin = connect(
  mapStateToProps,
  mapDispatchToProps,
  mergeProps
)(DropdownSigninComponent);

export default DropdownSignin;
