import React from "react";
import ReactDOM from "react-dom";
import {Icon} from 'react-fa';
import { connect } from 'react-redux';
import "../../styles/dropdown.scss";
import {actionChangeConnectionState, CONNECTION_STATE_NOT_CONNECTED} from '../../actions/connection'
import {actionToggleDropdown} from '../../actions/dropdown'
import {actionSwitchLang} from '../../actions/lang'
import translate from 'redux-polyglot/translate';
import 'flags.css'

class DropdownUserComponent extends React.Component {

  render() {

    let {user} = this.props;
    let arrow = <Icon name="angle-down"></Icon>;
    let hidden = 'hide';

    if (this.props.open) {
      arrow = <Icon name="angle-up"></Icon>;
      hidden = '';
    }

    return (
      <div className="dropdown">
      <div className="dropdown-header" onClick={this.props.onToggle}>
        <div className="dropdown-name">
          <span className="dropdown-arrow">{arrow}</span>
          <span className="dropdown-user">{this.props.name}</span>
        </div>
        <div className="dropdown-avatar">
          <div className="dropdown-avatar-photo"></div>
        </div>
      </div>
      <div className={"dropdown-menu "+hidden}>
        <div className="dropdown-menu-item" translate="yes" onClick={this.props.onLogout}><translate>Logout</translate></div>
        <div className="dropdown-menu-item lang-selection">
            <div className="lang-selection-item" onClick={ () => {this.props.onSwitchLang("fr")} }>
                <span className="flag-icon flag-icon-fr"></span>
                <span className="lang-text">FR</span>
            </div>
            <div className="lang-selection-item" onClick={ () => {this.props.onSwitchLang("en")} }>
                <span className="flag-icon flag-icon-gb"></span>
                <span className="lang-text">EN</span>
            </div>
        </div>
      </div>
    </div>
    )
  }
}

DropdownUserComponent = translate(DropdownUserComponent);

/******************************************************************/

const mapStateToProps = (state) => {

  return {
    open : state.dropdown.open,
    name : state.dropdown.name
  }
};

const mapDispatchToProps = (dispatch, ownProps) => {
  return {
    onLogout : () => {
      dispatch(actionChangeConnectionState(CONNECTION_STATE_NOT_CONNECTED))
    },
    onToggleDispatch : (open) => {
      dispatch(actionToggleDropdown(open))
    },
    onSwitchLang : (lang) => {
        dispatch(actionSwitchLang(lang))
    }

  }
};

const mergeProps = (stateProps, dispatchProps, ownProps) => {

  return {
    ...{ ...stateProps, ...dispatchProps },
    ...{
      onToggle : () => {
        dispatchProps.onToggleDispatch(stateProps.open)
      }
    }
  }
}

const DropdownUser = connect(
  mapStateToProps,
  mapDispatchToProps,
  mergeProps
)(DropdownUserComponent);

export default DropdownUser;
