import React from "react";
import DropdownUser from './dropdown/dropdownUser';
import DropdownSignin from './dropdown/dropdownSignin';
import { Link } from 'react-router'
import {Icon} from 'react-fa'
import { connect } from 'react-redux'
import "../styles/menu.scss"
import { actionChangeConnectionState, CONNECTION_STATE_CONNECTED, CONNECTION_STATE_NOT_CONNECTED, CONNECTION_STATE_ON_LOGIN, CONNECTION_STATE_ON_SUBSCRIBING } from "../actions/connection"
import { actionChangeSelection } from "../actions/selection"
import translate from 'redux-polyglot/translate';

class UserNotConnected extends React.Component {

  render() {

    return (
      <div className="menu-user-not-connected">
        <div className="menu-user-not-connected-item" onClick={this.props.onSubscribe}>
          <Icon className="menu-user-not-connected-item-icon" name="sign-in" />
          <translate>Sign in</translate>
        </div>
        <div className="menu-user-not-connected-item" onClick={this.props.onConnection}>
          <Icon className="menu-user-not-connected-item-icon" name="user" />
        <translate>Login</translate>
        </div>
      </div>
    )
  }

}

UserNotConnected = translate(UserNotConnected);

 class MenuComponent extends React.Component {

  render() {

    let menuUser = ""
    let selection = this.props.selection;

    switch (this.props.connected) {
    	case CONNECTION_STATE_NOT_CONNECTED:
				menuUser = <UserNotConnected onConnection={this.props.onLogin} onSubscribe={this.props.onSubscribe}/>
    		break;
		case CONNECTION_STATE_CONNECTED:
				menuUser = <DropdownUser />
			break;
		case CONNECTION_STATE_ON_LOGIN:
        case CONNECTION_STATE_ON_SUBSCRIBING:
				menuUser = <DropdownSignin />
			break;
    	default:

    }

    return (
      <div className="menu">
        <div className="menu-item-container">
          <Link className="menu-item" to='/'><Icon className="menu-item-icon" name="home"/><translate>Home</translate></Link>
          <Link className="menu-item" to='/movies' onClick={() => {this.props.onSwitchType('movies', selection)} }><Icon className="menu-item-icon" name="film" /><translate>Movies</translate></Link>
          <Link className="menu-item" to='/series' onClick={(that) => {this.props.onSwitchType('series', selection)} }><Icon className="menu-item-icon" name="tv" /><translate>Series</translate></Link>
          <Link className="menu-item" to='/games' onClick={(that) => {this.props.onSwitchType('games', selection)} }><Icon className="menu-item-icon" name="gamepad"/><translate>Games</translate></Link>
        </div>
        <div className="menu-user">
          {menuUser}
        </div>
      </div>
    )
  }
}

MenuComponent = translate(MenuComponent);

/****************************************************/

const mapStateToProps = (state) => {

  return {
    connected : state.connected,
    selection : state.selection
  }
};

const mapDispatchToProps = (dispatch) => {
  return {
    onLogin : () => {
      dispatch(actionChangeConnectionState(CONNECTION_STATE_ON_LOGIN))
    },
	onSubscribe : () => {
		console.log("test");
	},
    onSwitchType : (type, selection) => {
        let id = type == selection.type ? selection.id : 0 ;
        dispatch(actionChangeSelection(type, id));
    }
  }
};

const Menu = connect(
  mapStateToProps,
  mapDispatchToProps
)(MenuComponent);

export default Menu;
