import React from 'react' ;
import ReactDOM from 'react-dom';
import { createStore, applyMiddleware } from 'redux';
import { Router, Route, browserHistory } from 'react-router';
import ThunkMiddleware from 'redux-thunk';
import { Provider } from 'react-redux';
import App from './components/app';
import rootReducer from './reducers/rootReducer';
import { composeWithDevTools } from 'remote-redux-devtools';
import { polyglotMiddleware, throttleMiddleware } from './reducers/middlewares';
import { actionSwitchLang } from './actions/lang';


let store = createStore(rootReducer, {}, composeWithDevTools(
    applyMiddleware(polyglotMiddleware),
    applyMiddleware(throttleMiddleware),
    applyMiddleware(ThunkMiddleware),
));

store.dispatch(actionSwitchLang('fr'));

ReactDOM.render(
  <Provider store={store}>
    <Router history={browserHistory}>
      <Route path="/"  component={App}>
        <Route path="/:type"  component={App} />
      </Route>
    </Router>
  </Provider>
, document.getElementById("root"));
